<?php

	//
	//	This file is part of MythWeb,
	//	a php-based interface into MythTV.
	//
	//	(c) 2002 by Thor Sigvaldason and Isaac Richards
	//	MythWeb is distributed under the
	//	GNU GENERAL PUBLIC LICENSE version 2
	//	(see http://www.gnu.org)
	//

	
//
//	This file contains some classes 
//




//
//	A Time class that understands SQL formatted time,
//	human readable time and UNIX timestamps.
//
class TimeValue
{
	var $sqltime;
	var $unixtime;
	var $humantime;
   
 	var $fgColour;
	var $bgColour;
   
   	//
   	//	Set the background and foreground colours
   	//	for how time is displayed (at the top of
   	//	the listings table).
   	//
   
	function setColour($fg, $bg)
 	{
		$this->fgColour = $fg;
		$this->bgColour = $bg;
	}

	//
	//	Given colours, print yourself.
	// 
	
	function printYourself()
	{
		print("\t\t\t\t\t<TD BGCOLOR=\"$this->bgColour\">\n");
		print("\t\t\t\t\t\t&nbsp; <font style=\"color:$this->fgcolor\">$this->humantime</font>\n");
		print("\t\t\t\t\t</TD>\n");
	}

	function setVals($datestr)
	{
		$year = substr($datestr, 0, 4);
		$month = substr($datestr, 4, 2);
		$day = substr($datestr, 6, 2);
		$hour = substr($datestr, 8, 2);
 		$mins = substr($datestr, 10, 2);
		$secs = substr($datestr, 12, 2);

		if ((int)$mins >= 30)
		{
			$mins = 30;
			$sqlmins = 45;
		}
		else
		{
			$mins = 0;
			$sqlmins = 15;
		}

		$am = 1;
		if ($hour >= 12)
		{
			$am = 0;
		}

		$this->unixtime = mktime($hour, $mins, 0, $month, $day, $year);
		$this->humantime = date("h:i A", $this->unixtime);
		$this->sqltime = date('YmdHis', mktime($hour, $sqlmins, 50, $month, $day, $year));
	}
}



//
//	Container for recording data
//

class Recording
{
	var $chanid;
	var $channum;
	var $starttime;
	var $endtime;
	var $title;
	var $subtitle;
	var $description;
}


//
//	All about channels
//
class Channel
{
	var $channum;
	var $chanid;
	var $callsign;
	var $icon;

	function repathIcon()
	{
		$this->icon = "images/icons/" . basename($this->icon);
	}	

}

//
//	Programs class
//
class ProgramInfo
{
	var $title;
	var $subtitle;
	var $chanstr;
	var $chanid;
	var $startts;
	var $endts;
	var $progType;
	var $description;
	var $duration;
	var $recordColour;
	var $typeColour;
	var $whenRecord;
	var $airdate;
	var $stars;
	var $starstring;
	var $rater;
	var $rating;
	var $icon;

	function startTime()
	{
		return sprintf("%02d:%02d",
			(int) substr($this->startts, 8, 2),
			(int) substr($this->startts, 10, 2));
	}

	function willRecord()
	{
		return $this->whenRecord;
	}
	function alwaysRecord()
	{
		return $this->whenRecord & 1<<4;
	}
	function channelRecord()
	{
		return $this->whenRecord & 1<<3;
	}
	function singleRecord()
	{
		return $this->whenRecord & 1<<2;
	}
	function timeslotRecord()
	{
		return $this->whenRecord & 1<<1;
	}
	function setColours($a, $b)
	{
		$this->recordColour = $a;
		$this->typeColour = $b;
	}

	function printYourself($width, $anOffset)
	{

		print("<TD VALIGN=\"TOP\" COLSPAN=\"$width\" BGCOLOR=\"$this->typeColour\" STYLE=\"border:2px solid $this->recordColour; padding:4px;\">");
		print("<A STYLE=\"color:");
		if ($this->typeColour == $GLOBALS['list_default_colour']) print($GLOBALS['text_dark']);
		else print($GLOBALS['text_light']);
		print("\" HREF=\"main.php?mode=single&channel=$this->chanid&starttime=$this->startts&endtime=$this->endts&refoffset=$anOffset\">$this->title");
		if ($GLOBALS['includeSubTitle'] && strlen($this->subtitle) > 0) print(": $this->subtitle");

		if ($this->airdate > 0 && ($GLOBALS['includeReleaseYear'] || ($GLOBALS['includeReleaseYearForMovies'] && $this->smellsLikeMovie())))
			$parens = sprintf("%4d", $this->airdate);
		if (strlen($this->rating) > 0 && ($GLOBALS['includeRatings'] || ($GLOBALS['includeRatingsForMovies'] && $this->smellsLikeMovie())))
		{
			if ($parens)
				$parens .= ", ";
			$parens .= "<i>$this->rating</i>";
		}
		if ($parens)
			print " ($parens)";

		if ($GLOBALS['includeStarRating'] && strlen($this->stars) > 0) print " $this->starstring";
		if ($GLOBALS['includeDescription'] && strlen($this->description) > 0) print(" - $this->description");
		if ($GLOBALS['includeProgramType'] && strlen($this->progType) > 0) print(" ($this->progType)");
		print("</A>");
		print("</TD>");
	}

	function printYourselfDetailed()
	{
		print("<TR>");
		print("<TD VALIGN=\"TOP\" ALIGN=\"CENTER\" BGCOLOR=\"". $GLOBALS['list_bg_colour'] . "\">");
		print("&nbsp;&nbsp;<B>" . substr(getTimeString($this->startts), 11) . "&nbsp;");
		print("</TD>");
		print("<TD HEIGHT=\"100%\">");
		print("<TABLE VALIGN=\"TOP\" WIDTH=\"100%\"  HEIGHT=\"100%\" BGCOLOR=\"$this->recordColour\" CELLSPACING=\"0\" CELLPADDING=\"2\">");
		print("<TR VALIGN=\"TOP\"><TD VALIGN=\"TOP\" HEIGHT=\"100%\">");
		print("<TABLE VALIGN=\"TOP\" WIDTH=\"100%\" BORDER=\"0\" HEIGHT=\"100%\" BGCOLOR=\"$this->typeColour\" CELLSPACING=\"0\" CELLPADDING=\"2\">");
		print("<TR VALIGN=\"TOP\"><TD COLSPAN=\"2\" WIDTH=\"100%\" VALIGN=\"TOP\" ALIGN=\"CENTER\">");
		print("<A STYLE=\"color:");
		if ($this->typeColour == $GLOBALS['list_default_colour']) print($GLOBALS['text_dark']);
		else print($GLOBALS['text_light']);
		print("\" HREF=\"main.php?mode=single&channel=$this->chanid&starttime=$this->startts&endtime=$this->endts&refoffset=$anOffset\">");
		print("<B>$this->title</B>");
		print("</A>");
		print("</TD></TR>");
		if (strlen($this->subtitle) > 0) print("<TR VALIGN=\"TOP\" ALIGN=\"CENTER\"><TD COLSPAN=\"2\" VALIGN=\"TOP\"><i>$this->subtitle</i></TD></TR>");
		if (strlen($this->description) > 0) print("<TR VALIGN=\"TOP\"><TD COLSPAN=\"2\" VALIGN=\"TOP\">$this->description</TD></TR>");
		if (strlen($this->duration) > 0) print("<TR VALIGN=\"TOP\"><TD ALIGN=\"LEFT\" VALIGN=\"TOP\"><i>Duration: $this->duration</i></TD>");
		else print("<TR><TD WIDTH=\"50%\" >&nbsp;</TD>");
		if (strlen($this->progType) > 0) print("<TD WIDTH=\"50%\" ALIGN=\"RIGHT\" VALIGN=\"TOP\">($this->progType)</TD></TR>");
		else print("<TD WIDTH=\"50%\">&nbsp;</TD></TR>");
		print("</TABLE>");
		print("</TD></TR>");
		print("</TABLE>");
		print("</TD>");
		print("</TR>");
	}

	function smellsLikeMovie()
	{
		if ($this->rater == "MPAA"
		|| ($this->airdate && $this->stars > 0))
			return TRUE;

		if ($this->airdate
		&& $GLOBALS['includeMoviesMadeForTV']
		&& $this->duration > 70)
			switch ($this->progType)
			{
				case "Drama":
				case "Doc":
				case "Mystery":
				case "Musical":
				case "Action":
				case "Comedy":
				case "War":
				case "Romance":
				case "Crime":
				case "SciFi":
				case "Horror":
					return TRUE;
			}
		return FALSE;
	}
}


?>
